/*
 * Copyright (c) 2023 DuckDuckGo
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.duckduckgo.savedsites.impl.sync.algorithm

import com.duckduckgo.savedsites.api.models.BookmarkFolder
import com.duckduckgo.savedsites.api.models.SavedSite.Bookmark

interface SavedSitesSyncPersisterStrategy {

    fun processBookmarkFolder(
        folder: BookmarkFolder,
        children: List<String>,
    )

    /**
     * Favourites folder have the same id and names across platforms
     * All we want to do here is deal with the children and mark them as favourites or not
     * Other methods deal with inserting the actual Entity
     */
    fun processFavouritesFolder(
        favouriteFolder: String,
        children: List<String>,
    )

    fun processBookmark(
        bookmark: Bookmark,
        folderId: String,
    )
}
